@@ -4,10 +4,10 @@ import time
 import threading
 import warnings
 
-from message import Message
-from enums.PTPMode import PTPMode
-from enums.CommunicationProtocolIDs import CommunicationProtocolIDs
-from enums.ControlValues import ControlValues
+from .message import Message
+from .enums import PTPMode
+from .enums.CommunicationProtocolIDs import CommunicationProtocolIDs
+from .enums.ControlValues import ControlValues
 
 
 class Dobot:
@@ -224,7 +224,7 @@ class Dobot:
         msg.id = CommunicationProtocolIDs.SET_PTP_CMD
         msg.ctrl = ControlValues.THREE
         msg.params = bytearray([])
-        msg.params.extend(bytearray([mode]))
+        msg.params.extend(bytearray([mode.value]))
         msg.params.extend(bytearray(struct.pack('f', x)))
         msg.params.extend(bytearray(struct.pack('f', y)))
         msg.params.extend(bytearray(struct.pack('f', z)))
@@ -249,6 +249,16 @@ class Dobot:
         msg.ctrl = ControlValues.ONE
         return self._send_command(msg)
 
+    """
+        Wait command
+    """
+    def _set_wait_cmd(self, ms):
+        msg = Message()
+        msg.id = 110
+        msg.ctrl = 0x03
+        msg.params = bytearray(struct.pack('I', ms))
+        return self._send_command(msg)
+
     """
         Stop command
     """
@@ -258,6 +268,29 @@ class Dobot:
         msg.ctrl = ControlValues.ONE
         return self._send_command(msg)
 
+    def _get_eio_level(self, address):
+        msg = Message()
+        msg.id = CommunicationProtocolIDs.SET_GET_EIO
+        msg.ctrl = ControlValues.ZERO
+        msg.params = bytearray([])
+        msg.params.extend(bytearray([address]))
+        return self._send_command(msg)
+
+    def _set_eio_level(self, address, level):
+        msg = Message()
+        msg.id = CommunicationProtocolIDs.SET_GET_EIO
+        msg.ctrl = ControlValues.ONE
+        msg.params = bytearray([])
+        msg.params.extend(bytearray([address]))
+        msg.params.extend(bytearray([level]))
+        return self._send_command(msg)
+
+    def get_eio(self, addr):
+        return self._get_eio_level(addr)
+
+    def set_eio(self, addr, val):
+        return self._set_eio_level(addr, val)
+
     def close(self):
         self._on = False
         self.lock.acquire()
@@ -283,6 +316,9 @@ class Dobot:
         self._set_ptp_common_params(velocity, acceleration)
         self._set_ptp_coordinate_params(velocity, acceleration)
 
+    def wait(self, ms):
+        self._set_wait_cmd(ms)
+
     def pose(self):
         response = self._get_pose()
         x = struct.unpack_from('f', response.params, 0)[0]
